function optimal_pole = M12_pole(impulse_response,delay)  

%M12_POLE Compute an optimal dominating pole by minimizing the performance index J given in section 7.1.
%         This method requires a priori knowledge about the system impulse response.
%
%   OPTIMAL_POLE = M12_POLE(impulse_response,delay)  
% 
%   The OPTIMAL POLE is derived by minimizing the performance index J.
%  
%   IMPULSE_RESPONSE: This impulse response is given in time domain, according to a priori 
%       knowlegde of the true dynamics.  
%
%   DELAY: The true delay corresponds to the true delay of the system. 

%   Piya Kovintavewat
%   Revision:1       Date: 1998/10/15 

ir_length=length(impulse_response);
h = impulse_response(:);
square_h = h'*h;

%-----------------------M1 calculation
m1_temp=0;
for i=0:ir_length-1
    m1_temp = m1_temp + i*(h(i+1)^2);
end
M1= m1_temp/square_h;

%-----------------------M2 calculation
h(ir_length+1)=0;   h(ir_length+2)=0;
m2_temp=0;
for i=0:ir_length-1
    m2_temp = m2_temp + h(i+2)*( -(i+1)*h(i+3) + (2*i+1)*h(i+2) - i*h(i+1) );
    %m3_temp = m3_temp + ( (h(i+2)-h(i+1)) * ( i*( h(i+2)-h(i+1) ) ) );
    %m4_temp = m4_temp + ( i* (h(i+2)-h(i+1))^2 );
    %m2_temp=m3_temp=m4_temp
end
M2= m2_temp/square_h;

%-----------------------Optimum pole calculation 
if delay > 1
   ii = 1:ir_length;
   D3 = (h(ii)'*h(ii+1))/square_h;
   M1 = M1+delay-1;
   M2 = M2+(2*(delay-1)*(1-D3)); 
end

optimal_pole = (2*M1-1-M2) / ( 2*M1 - 1 + sqrt( 4*M1*M2 - M2^2 - 2*M2 ) );
