function fit = fit_arx(ze,zv,NN)

%FIT_ARX  Compute the FIT of error of LS-estimates of ARX/FIR model
%
%   FIT = FIT_ARX(ze,zv,NN) 
% 
%   This FIT is calculated from based on ARX model
%   A(q) y(t) = B(q) u(t-nk) + e(t)
%   by using cross validation technique to varify the model.
%  
%   ZE: the output-input data ZE=[ye ue] for estimation process,
%       with ye and ue as column vectors.
%
%   ZV: the output-input data ZV=[yv uv] having the same size for validation process,
%       with yv and uv as column vectors.
%
%   NN: NN = [na nb nk], the orders and treu delays of the model.
%       if na=0, the model will correspond to FIR model.

%   Piya Kovintavewat
%   Revision:1       Date: 1998/10/15 

vz=1; if size(ze)==size(zv), if norm(ze-zv)<eps, vz=0; end;  end;
maxlength = length(ze(:,1));
NA=NN(1);  NB=NN(2);  NK=NN(3);

PHI=[]; PHIV=[]; TH=[];       
[TH,PHI,PHIV]= mo_arxstruc(ze,zv,[NA NB NK]);
nmax = max([NA+1, NB+NK]);
jj=nmax:maxlength;
if vz==0, ysim=PHI*TH; else, ysim=PHIV*TH; end
fit  = norm(ysim-zv(jj,1))/sqrt(length(jj));

